..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Releases
========

We follow `semantic versioning <http://semver.org/>`_ and `PEP-0440
<https://www.python.org/dev/peps/pep-0440/>`_ release numbering practices.

Invenio v3.x
------------

*Unreleased*

Invenio v3.0 will be released when the Invenio code base is fully split into a
set of standalone independent Python packages.

Invenio v2.x
------------

*Semi-stable*

Invenio v2.x code base is a hybrid architecture that uses Flask web
development framework combined with Invenio v1.x framework.

.. note::

    The 2.x code base is not suitable for production systems, and will not
    receive any further development nor security fixes.

Released versions include:

Invenio v2.1:

* `v2.1.1 <https://github.com/inveniosoftware/invenio/releases/tag/v2.1.1>`_ - released 2015-09-01
* `v2.1.0 <https://github.com/inveniosoftware/invenio/releases/tag/v2.1.0>`_ - released 2015-06-16

Invenio v2.0:

* `v2.0.6 <https://github.com/inveniosoftware/invenio/releases/tag/v2.0.6>`_ - released 2015-09-01
* `v2.0.5 <https://github.com/inveniosoftware/invenio/releases/tag/v2.0.5>`_ - released 2015-07-17
* `v2.0.4 <https://github.com/inveniosoftware/invenio/releases/tag/v2.0.4>`_ - released 2015-06-01
* `v2.0.3 <https://github.com/inveniosoftware/invenio/releases/tag/v2.0.3>`_ - released 2015-05-15
* `v2.0.2 <https://github.com/inveniosoftware/invenio/releases/tag/v2.0.2>`_ - released 2015-04-17
* `v2.0.1 <https://github.com/inveniosoftware/invenio/releases/tag/v2.0.1>`_ - released 2015-03-20
* `v2.0.0 <https://github.com/inveniosoftware/invenio/releases/tag/v2.0.0>`_ - released 2015-03-04

Invenio v1.x
------------

*Stable*

Invenio v1.x code base is suitable for stable production. It uses legacy
technology and custom web development framework.

.. note::

    Invenio v1.x is in feature freeze and will only receive important bug and
    security fixes.

Released versions include:

Invenio v1.2:

* `v1.2.2 <https://github.com/inveniosoftware/invenio/releases/tag/v1.2.2>`_ - released 2016-11-25
* `v1.2.1 <https://github.com/inveniosoftware/invenio/releases/tag/v1.2.1>`_ - released 2015-05-21
* `v1.2.0 <https://github.com/inveniosoftware/invenio/releases/tag/v1.2.0>`_ - released 2015-03-03

Invenio v1.1:

* `v1.1.7 <https://github.com/inveniosoftware/invenio/releases/tag/v1.1.7>`_ - released 2016-11-20
* `v1.1.6 <https://github.com/inveniosoftware/invenio/releases/tag/v1.1.6>`_ - released 2015-05-21
* `v1.1.5 <https://github.com/inveniosoftware/invenio/releases/tag/v1.1.5>`_ - released 2015-03-02
* `v1.1.4 <https://github.com/inveniosoftware/invenio/releases/tag/v1.1.4>`_ - released 2014-08-31
* `v1.1.3 <https://github.com/inveniosoftware/invenio/releases/tag/v1.1.3>`_ - released 2014-02-25
* `v1.1.2 <https://github.com/inveniosoftware/invenio/releases/tag/v1.1.2>`_ - released 2013-08-19
* `v1.1.1 <https://github.com/inveniosoftware/invenio/releases/tag/v1.1.1>`_ - released 2012-12-21
* `v1.1.0 <https://github.com/inveniosoftware/invenio/releases/tag/v1.1.0>`_ - released 2012-10-21

Invenio v1.0:

* `v1.0.10 <https://github.com/inveniosoftware/invenio/releases/tag/v1.0.10>`_ - released 2016-11-09
* `v1.0.9 <https://github.com/inveniosoftware/invenio/releases/tag/v1.0.9>`_ - released 2015-05-21
* `v1.0.8 <https://github.com/inveniosoftware/invenio/releases/tag/v1.0.8>`_ - released 2015-03-02
* `v1.0.7 <https://github.com/inveniosoftware/invenio/releases/tag/v1.0.7>`_ - released 2014-08-31
* `v1.0.6 <https://github.com/inveniosoftware/invenio/releases/tag/v1.0.6>`_ - released 2014-01-31
* `v1.0.5 <https://github.com/inveniosoftware/invenio/releases/tag/v1.0.5>`_ - released 2013-08-19
* `v1.0.4 <https://github.com/inveniosoftware/invenio/releases/tag/v1.0.4>`_ - released 2012-12-21
* `v1.0.3 <https://github.com/inveniosoftware/invenio/releases/tag/v1.0.3>`_ - released 2012-12-19
* `v1.0.2 <https://github.com/inveniosoftware/invenio/releases/tag/v1.0.2>`_ - released 2012-10-19
* `v1.0.1 <https://github.com/inveniosoftware/invenio/releases/tag/v1.0.1>`_ - released 2012-06-28
* `v1.0.0 <https://github.com/inveniosoftware/invenio/releases/tag/v1.0.0>`_ - released 2012-02-29
* `v1.0.0-rc0 <https://github.com/inveniosoftware/invenio/releases/tag/v1.0.0-rc0>`_ - released 2010-12-21

Invenio v0.x
------------

Invenio v0.x code base was developed and used in production instances
since 2002. The code base is interesting only for archaeological purposes.

Released versions include:

* `v0.99.9 <https://github.com/inveniosoftware/invenio/releases/tag/v0.99.9>`_ - released 2014-01-31
* `v0.99.8 <https://github.com/inveniosoftware/invenio/releases/tag/v0.99.8>`_ - released 2013-08-19
* `v0.99.7 <https://github.com/inveniosoftware/invenio/releases/tag/v0.99.7>`_ - released 2012-12-18
* `v0.99.6 <https://github.com/inveniosoftware/invenio/releases/tag/v0.99.6>`_ - released 2012-10-18
* `v0.99.5 <https://github.com/inveniosoftware/invenio/releases/tag/v0.99.5>`_ - released 2012-02-21
* `v0.99.4 <https://github.com/inveniosoftware/invenio/releases/tag/v0.99.4>`_ - released 2011-12-19
* `v0.99.3 <https://github.com/inveniosoftware/invenio/releases/tag/v0.99.3>`_ - released 2010-12-13
* `v0.99.2 <https://github.com/inveniosoftware/invenio/releases/tag/v0.99.2>`_ - released 2010-10-20
* `v0.99.1 <https://github.com/inveniosoftware/invenio/releases/tag/v0.99.1>`_ - released 2008-07-10
* `v0.99.0 <https://github.com/inveniosoftware/invenio/releases/tag/v0.99.0>`_ - released 2008-03-27
* `v0.92.1 <https://github.com/inveniosoftware/invenio/releases/tag/v0.92.1>`_ - released 2007-02-20
* `v0.92.0. <https://github.com/inveniosoftware/invenio/releases/tag/v0.92.0>`_ - released 2006-12-22
* `v0.90.1 <https://github.com/inveniosoftware/invenio/releases/tag/v0.90.1>`_ - released 2006-07-23
* `v0.90.0 <https://github.com/inveniosoftware/invenio/releases/tag/v0.90.0>`_ - released 2006-06-30
* `v0.7.1 <https://github.com/inveniosoftware/invenio/releases/tag/v0.7.1>`_ - released 2005-05-04
* `v0.7.0 <https://github.com/inveniosoftware/invenio/releases/tag/v0.7.0>`_ - released 2005-04-06
* `v0.5.0 <https://github.com/inveniosoftware/invenio/releases/tag/v0.5.0>`_ - released 2004-12-17
* `v0.3.3 <https://github.com/inveniosoftware/invenio/releases/tag/v0.3.3>`_ - released 2004-07-16
* `v0.3.2 <https://github.com/inveniosoftware/invenio/releases/tag/v0.3.2>`_ - released 2004-05-12
* `v0.3.1 <https://github.com/inveniosoftware/invenio/releases/tag/v0.3.1>`_ - released 2004-03-12
* `v0.3.0 <https://github.com/inveniosoftware/invenio/releases/tag/v0.3.0>`_ - released 2004-03-05
* `v0.1.2 <https://github.com/inveniosoftware/invenio/releases/tag/v0.1.2>`_ - released 2003-12-21
* `v0.1.1 <https://github.com/inveniosoftware/invenio/releases/tag/v0.1.1>`_ - released 2003-12-19
* `v0.1.0 <https://github.com/inveniosoftware/invenio/releases/tag/v0.1.0>`_ - released 2003-12-04
* `v0.0.9 <https://github.com/inveniosoftware/invenio/releases/tag/v0.0.9>`_ - released 2002-08-01
